@@ -22,13 +22,19 @@
 
 /***************************************************************************
  *   CONTRIBUTORS
+ *   <NE brii i NE mijenjaj!>
+ *   Danas e biti toplo i sunano.
  *   [Hrvatski]
  *   Prevela s engleskog na hrvatski: Anica Sean [Ancica Secan].
  *   Vrijeme: 22. travnja 2003. godine [utorak].
  *   Updateano za 2.0.5: 19. lipnja 2003. godine [etvrtak].
+ *   Updateano za 2.0.11: 30. sijenja 2005. godine [nedjelja].
+ *   Verzija: 3.3.3.
  *   Url: http://ancica.sunceko.net.
- *   E-mail: ancica@sunceko.net.
  *   Danas e biti toplo i sunano.
+ *   Original ovog mog prijevoda moe skinuti sa www.phpbb.com.
+ *   Danas e biti toplo i sunano.
+ *   </NE brii i NE mijenjaj!>
  ***************************************************************************/
 
 //
@@ -104,7 +110,7 @@ $lang['Database_Utilities'] = 'Alati za bazu';
 $lang['Restore'] = 'Restore';
 $lang['Backup'] = 'Backup';
 $lang['Restore_explain'] = 'Ovdje moete izvriti potpuni povrat svih phpBB tabela iz [ranije] snimljene datoteke.<br />Ako Va server podrava tu opciju, moete uploadati gzip-kompresiranu tekst datoteku koja e automatski biti dekompresirana.<br /><b>UPOZORENJE:</b> ovime ete prepisati postojee podatke.<br />Proces moe [po]trajati podue, stoga, ostanite na ovoj stranici dok operacija ne bude zgotovljena.';
-$lang['Backup_explain'] = 'Ovdje moete backupirati [napraviti kopiju] sve Vae phpBB podatke.<br />Ako imate bilo kakve dodatne tabele, u istoj bazi sa phpBB, koje biste eljeli backupirati, unesite njihova imena, odvojena zarezima, u <i>Dodatne tabele</i>.<br />Ako Va server podrava tu opciju, moete koristiti gzip kompresiju kako biste smanjili veliinu datoteke prije downloadiranja.';
+$lang['Backup_explain'] = 'Ovdje moete backupirati [napraviti kopiju] sve Vae phpBB podatke.<br />Ako imate bilo kakve dodatne tabele, u istoj bazi s phpBB, koje biste eljeli backupirati, unesite njihova imena, odvojena zarezima, u <i>Dodatne tabele</i>.<br />Ako Va server podrava tu opciju, moete koristiti gzip kompresiju kako biste smanjili veliinu datoteke prije downloadiranja.';
 
 $lang['Backup_options'] = 'Backup opcije';
 $lang['Start_backup'] = 'Zaponite Backup';
@@ -139,8 +145,8 @@ $lang['Look_up_User'] = 'Potraite korisnika/cu';
 $lang['Look_up_Group'] = 'Potraite grupu';
 $lang['Look_up_Forum'] = 'Potraite forum';
 
-$lang['Group_auth_explain'] = 'Ovdje moete definirati dozvole i moderatorski status svake Korisnike grupe.<br />Obratite panju na individualne postavke koje ste dodijelili korisniku/ci - ako su drugaije od postavki koje ste dodijelili Korisnikoj grupi korisnik/ca e i dalje moi koristiti dozvole koje ste mu/joj individualno dodijelili [ukoliko se dogodi da postavke ne budu identine - bit` ete obavijeteni o tome].';
-$lang['User_auth_explain'] = 'Ovdje moete definirati dozvole i moderatorski status svakog/e korisnika/ce.<br />Obratite panju na postavke koje ste dodijelili Korisnikoj grupi (ako je koje korisnik/ca lan/ica) - ako su drugaije od postavki koje ste dodijelili individualno korisniku/ci on/a e i dalje moi koristiti dozvole koje ste dodijelili Korisnikoj grupi [ukoliko se dogodi da postavke ne budu identine - bit` ete obavijeteni o tome].';
+$lang['Group_auth_explain'] = 'Ovdje moete definirati dozvole i moderatorski status svake Korisnike grupe.<br />Obratite panju na individualne postavke koje ste dodijelili korisniku/ci - ako su drugaije od postavki koje ste dodijelili Korisnikoj grupi korisnik/ca e i dalje moi koristiti dozvole koje ste mu/joj individualno dodijelili [ukoliko se dogodi da postavke ne budu identine - bit ete obavijeteni o tome].';
+$lang['User_auth_explain'] = 'Ovdje moete definirati dozvole i moderatorski status svakog/e korisnika/ce.<br />Obratite panju na postavke koje ste dodijelili Korisnikoj grupi [ako je koje korisnik/ca lan/ica] - ako su drugaije od postavki koje ste dodijelili individualno korisniku/ci on/a e i dalje moi koristiti dozvole koje ste dodijelili Korisnikoj grupi [ukoliko se dogodi da postavke ne budu identine - bit ete obavijeteni o tome].';
 $lang['Forum_auth_explain'] = 'Ovdje moete [jednostavnim ili naprednim sueljem] definirati mogunosti pristupa forumima.<br />Obratite panju na to da se promjenom dozvola pristupa odreuje i koji/e korisnici/e e imati prava koritenja/upravljanja forumima.';
 
 $lang['Simple_mode'] = 'Jednostavno suelje';
@@ -208,7 +214,7 @@ $lang['Click_return_forumauth'] = 'Kliknite %sovdje%s za povratak na dozvole for
 //
 
 $lang['Ban_control'] = 'Iskljuivanje';
-$lang['Ban_explain'] = 'Ovdje moete iskljuiti [zabraniti pristup] korisnika/cu sa foruma.<br />Moete iskljuiti korisnika/cu, IP adresu pristupa, adresu pruatelja usluga...<br />Ovime se iskljuenoj osobi moe zabraniti pristup ak i na Poetnu stranicu foruma.<br />Da biste sprijeili iskljuenu osobu da se ponovo registrira, moete iskljuiti i odreenu e-mail adresu [iskljuivanje samo e-mail adrese nee sprijeiti osobu da se loginira i posta].';
+$lang['Ban_explain'] = 'Ovdje moete iskljuiti [zabraniti pristup] korisnika/cu s foruma.<br />Moete iskljuiti korisnika/cu, IP adresu pristupa, adresu pruatelja usluga...<br />Ovime se iskljuenoj osobi moe zabraniti pristup ak i na Poetnu stranicu foruma.<br />Da biste sprijeili iskljuenu osobu da se ponovo registrira, moete iskljuiti i odreenu e-mail adresu [iskljuivanje samo e-mail adrese nee sprijeiti osobu da se loginira i posta].';
 $lang['Ban_explain_warn'] = 'Unoenje opsega IP adresa rezultira time da e sve IP adrese, od poetne do zadnje, biti dodane na listu iskljuenih [blokiranih] IP adresa.<br />Pokuajte minimizirati broj dodatnih IP adresa unoenjem zvjezdica (*) gdje god je to mogue.<br />Ako stvarno morate blokirati opseg adresa, pazite da bude to manji.';
 
 $lang['Select_username'] = 'Izaberite korisniko ime';
@@ -298,7 +304,7 @@ $lang['Allow_name_change'] = 'Dozvolite promjene korisnikih imena';
 $lang['Avatar_settings'] = 'Postavke Avatara';
 $lang['Allow_local'] = 'Omoguite galeriju Avatara';
 $lang['Allow_remote'] = 'Omoguite linkane Avatare';
-$lang['Allow_remote_explain'] = '<i>Avatari koji su smjeteni na drugim i pozivaju se sa tih stranica.</i>';
+$lang['Allow_remote_explain'] = '<i>Avatari koji su smjeteni na drugim i pozivaju se s tih stranica.</i>';
 $lang['Allow_upload'] = 'Omoguite uploadanje Avatara';
 $lang['Max_filesize'] = 'Max veliina Avatara';
 $lang['Max_filesize_explain'] = '<i>Za uploadane Avatare.</i>';
@@ -527,7 +533,7 @@ $lang['Click_return_wordadmin'] = 'Kliknite %sovdje%s za povratak na Administrac
 // Mass Email
 //
 
-$lang['Mass_email_explain'] = 'Ovdje moete poslati e-mail svim korisnicima/ama foruma odnosno lanovima/icama Korisnikih grupa.<br />E-mail e otii s e-mail adrese administratora/ice foruma; primatelji/ce e biti navedeni/e u BCC [Na znanje] odjeljku.<br />Ukoliko je primatelja/ica puno, moda e slanje e-maila potrajati neko vrijeme - bit` ete obavijeteni kada e-mail bude poslan.';
+$lang['Mass_email_explain'] = 'Ovdje moete poslati e-mail svim korisnicima/ama foruma odnosno lanovima/icama Korisnikih grupa.<br />E-mail e otii s e-mail adrese administratora/ice foruma; primatelji/ce e biti navedeni/e u BCC [Na znanje] odjeljku.<br />Ukoliko je primatelja/ica puno, moda e slanje e-maila potrajati neko vrijeme - bit ete obavijeteni kada e-mail bude poslan.';
 $lang['Compose'] = 'Compose'; 
 
 $lang['Recipients'] = 'Primatelji/ce'; 
@@ -571,7 +577,7 @@ $lang['Disallow_explain'] = 'Ovdje moete dodavati/izbrisati korisnika imena pod
 
 $lang['Delete_disallow'] = 'Izbriite';
 $lang['Delete_disallow_title'] = 'Izbriite nedoputeno korisniko ime';
-$lang['Delete_disallow_explain'] = 'Korisniko ime moete izbrisati tako da ga izaberete sa liste i kliknete na gumb Izbriite.';
+$lang['Delete_disallow_explain'] = 'Korisniko ime moete izbrisati tako da ga izaberete s liste i kliknete na gumb Izbriite.';
 
 $lang['Add_disallow'] = 'Dodajte';
 $lang['Add_disallow_title'] = 'Dodajte nedoputeno korisniko ime';
@@ -607,7 +613,7 @@ $lang['Create_theme'] = 'Kreirajte temu';
 $lang['Create_theme_explain'] = 'Donjom formom moete kreirati novu temu za izabrani predloak.<br />Kod unoenja boja [za koje koristite heksadecimalni oblik] nemojte unositi znak ljestve (#) [npr.: CCCCCC je pravilno; #CCCCCC nije].';
 
 $lang['Export_themes'] = 'Eksportirajte teme';
-$lang['Export_explain'] = 'Ovdje moete eksportirati podatke teme za izabrani predloak.<br />Izaberite predloak sa donje liste i skripta e kreirati konfiguracijsku datoteku teme te ju pokuati spremiti u izabranu mapu predloaka.<br />Ukoliko ju nee moi spremiti, predloit` e Vam da ju downloadirate.<br />Da bi skripta mogla spremiti datoteku, morate dati pravo pristupa webserveru za izabranu mapu predloaka.<br />Za vie informacija o ovome, pogledajte phpBB 2 vodi.';
+$lang['Export_explain'] = 'Ovdje moete eksportirati podatke teme za izabrani predloak.<br />Izaberite predloak sa donje liste i skripta e kreirati konfiguracijsku datoteku teme te ju pokuati spremiti u izabranu mapu predloaka.<br />Ukoliko ju nee moi spremiti, predloit e Vam da ju downloadirate.<br />Da bi skripta mogla spremiti datoteku, morate dati pravo pristupa webserveru za izabranu mapu predloaka.<br />Za vie informacija o ovome, pogledajte phpBB 2 vodi.';
 
 $lang['Theme_installed'] = 'Tema je uspjeno instalirana.';
 $lang['Style_removed'] = 'Izabrani stil je izbrisan iz baze.<br />Da biste stil potpuno uklonili iz sistema morate izbrisati odgovarajui stil iz mape predloaka.';
@@ -681,14 +687,14 @@ $lang['Welcome_install'] = 'Dobro doli u phpBB 2 instalaciju';
 $lang['Initial_config'] = 'Osnovna konfiguracija';
 $lang['DB_config'] = 'Konfiguracija baze';
 $lang['Admin_config'] = 'Admin konfiguracija';
-$lang['continue_upgrade'] = 'Kada downloadirate konfiguracijsku datoteku, moete kliknuti na gumb \'Nastavite nadogradnju\' kako biste nastavili sa nadogradnjom.<br />Priekajte s uploadiranjem konfiguracijske datoteke dok proces nadogradnje ne zavri.';
+$lang['continue_upgrade'] = 'Kada downloadirate konfiguracijsku datoteku, moete kliknuti na gumb \'Nastavite nadogradnju\' kako biste nastavili s nadogradnjom.<br />Priekajte s uploadiranjem konfiguracijske datoteke dok proces nadogradnje ne zavri.';
 $lang['upgrade_submit'] = 'Nastavite nadogradnju';
 
 $lang['Installer_Error'] = 'Dolo je do greke prilikom instalacije.';
 $lang['Previous_Install'] = 'Detektirana je prethodna instalacija.';
 $lang['Install_db_error'] = 'Dolo je do greke prilikom pokuaja nadogradnje baze.';
 
-$lang['Re_install'] = 'Prethodna instalacija je jo uvijek aktivna.<br />Ukoliko elite reinstalirati phpBB 2 kliknite na Da gumb ispod.<br />Obratite panju na to da e to dovesti do unitenja svih postojeih podataka i backupova.<br />Korisniko ime i zaporka administratora/ice, koje ste koristili za loginiranje, bit` e ponovo kreirani nakon reinstalacije; ostale postavke nee biti sauvane.<br />Dobro razmislite prije klika na Da.';
+$lang['Re_install'] = 'Prethodna instalacija je jo uvijek aktivna.<br />Ukoliko elite reinstalirati phpBB 2 kliknite na Da gumb ispod.<br />Obratite panju na to da e to dovesti do unitenja svih postojeih podataka i backupova.<br />Korisniko ime i zaporka administratora/ice, koje ste koristili za loginiranje, bit e ponovo kreirani nakon reinstalacije; ostale postavke nee biti sauvane.<br />Dobro razmislite prije klika na Da.';
 
 $lang['Inst_Step_0'] = 'Hvala Vam to ste izabrali phpBB 2.<br />Da biste zavrili instalaciju, ispunite traene podatke ispod.<br />Baza u koju instalirate bi ve trebala postojati.<br />Ukoliko instalirate u bazu koja koristi ODBC, npr. MS Access, trebali biste prvo kreirati DSN za nju prije nastavka.';
 
@@ -708,13 +714,13 @@ $lang['Admin_Username'] = 'Korisniko ime administratora/ice';
 $lang['Admin_Password'] = 'Zaporka administratora/ice';
 $lang['Admin_Password_confirm'] = 'Zaporka administratora/ice [potvrdite]';
 
-$lang['Inst_Step_2'] = 'Korisniko ime administratora/ice je kreirano.<br />Ovime je osnovna instalacija zavrena.<br />Otvorit` e Vam se stranica na kojoj ete moi izadministrirati Vau novu instalaciju.<br />Provjerite postavke Ope konfiguracije i uredite sve to treba.<br />Hvala Vam to ste izabrali phpBB 2.';
+$lang['Inst_Step_2'] = 'Korisniko ime administratora/ice je kreirano.<br />Ovime je osnovna instalacija zavrena.<br />Otvorit e Vam se stranica na kojoj ete moi izadministrirati Vau novu instalaciju.<br />Provjerite postavke Ope konfiguracije i uredite sve to treba.<br />Hvala Vam to ste izabrali phpBB 2.';
 
-$lang['Unwriteable_config'] = 'Konfiguracijsku datoteku nije mogue editirati.<br /> Kopija konfiguracijske datoteke bit` e downloadirana kada kliknete na donji gumb.<br />Uploadajte tu datoteku u istu mapu gdje ste uploadirali i phpBB 2.<br />Tada ete se moi loginirati koristei korisniko ime i zaporku administratora/ice, koje ste unijeli u prethodnoj formi, te otii u AdministratorPanel da provjerite postavke Ope konfiguracije.<br />Hvala Vam to ste izabrali phpBB 2.';
+$lang['Unwriteable_config'] = 'Konfiguracijsku datoteku nije mogue editirati.<br /> Kopija konfiguracijske datoteke bit e downloadirana kada kliknete na donji gumb.<br />Uploadajte tu datoteku u istu mapu gdje ste uploadirali i phpBB 2.<br />Tada ete se moi loginirati koristei korisniko ime i zaporku administratora/ice, koje ste unijeli u prethodnoj formi, te otii u AdministratorPanel da provjerite postavke Ope konfiguracije.<br />Hvala Vam to ste izabrali phpBB 2.';
 $lang['Download_config'] = 'Downloadirajte konfiguracijsku datoteku';
 
 $lang['ftp_choose'] = 'Izaberite metodu downloada';
-$lang['ftp_option'] = '<br />S obzirom da su FTP ekstenzije omoguene u ovoj verziji PHP-a, bit` e Vam dana mogunost da prvo putem FTP-a postavite konfiguracijsku datoteku na mjesto.';
+$lang['ftp_option'] = '<br />S obzirom da su FTP ekstenzije omoguene u ovoj verziji PHP-a, bit e Vam dana mogunost da prvo putem FTP-a postavite konfiguracijsku datoteku na mjesto.';
 $lang['ftp_instructs'] = 'Izabrali ste FTP-iranje datoteke.<br />Unesite informacije ispod kako biste olakali proces.<br />FTP putanja mora biti tono do phpBB 2 instalacije.';
 $lang['ftp_info'] = 'Unesite FTP informacije';
 $lang['Attempt_ftp'] = 'Pokuajte FTP-irati konfiguracijsku datoteku';
