@@ -7,9 +7,9 @@
  *     copyright            : (C) 2001 The phpBB Group
  *     email                : support@phpbb.com
  *
- *     Translation: Mr.LonelyWinter < mr_lonely_winter@yahoo.com > 
+ *     Translation: SuperToy_nc < SuperToy_nc@yahoo.com > 
  *
- *     $Id: lang_admin.php,v 1.35.2.3 2002/06/27 20:06:44 thefinn Exp $
+ *     $Id: lang_admin.php,v 1.35.2.9 2003/06/10 00:31:19 psotfx Exp $
  *
  ****************************************************************************/
 
@@ -22,6 +22,11 @@
  *
  ***************************************************************************/
 
+/* CONTRIBUTORS
+	2002-12-15	Philip M. White (pwhite@mailhaven.com)
+		Fixed many minor grammatical mistakes
+*/
+
 //
 // Format is same as lang_main
 //
@@ -36,21 +41,21 @@ $lang['Groups'] = 'Group Admin';
 $lang['Forums'] = 'Forum Admin';
 $lang['Styles'] = 'Styles Admin';
 
-$lang['Configuration'] = 'õ駤';
+$lang['Configuration'] = 'õ駤ҷ';
 $lang['Permissions'] = '͹حҵ';
-$lang['Manage'] = 'èѴ';
+$lang['Manage'] = 'õ駤ҵ͡';
 $lang['Disallow'] = 'ͷ͹حҵ';
-$lang['Prune'] = 'źǢѵѵ';
+$lang['Prune'] = 'źǢͷաõͺ';
 $lang['Mass_Email'] = ' Email 繡';
 $lang['Ranks'] = 'дѺ';
 $lang['Smilies'] = 'ٻ';
-$lang['Ban_Management'] = 'Ǻǧ';
+$lang['Ban_Management'] = '';
 $lang['Word_Censor'] = 'ǧ';
 $lang['Export'] = '͡';
 $lang['Create_new'] = 'ҧ';
 $lang['Add_new'] = '';
-$lang['Backup_DB'] = 'ͧ';
-$lang['Restore_DB'] = '׹';
+$lang['Backup_DB'] = 'ͧҹ';
+$lang['Restore_DB'] = '׹ҹ';
 
 
 //
@@ -63,14 +68,14 @@ $lang['Admin_intro'] = 'ͺس phpBB. ˹ҹʴʶԵԵҧͧ. سöѺҷ˹ҹ¤ԡ <u>Admin
 $lang['Main_index'] = 'Forum Index';
 $lang['Forum_stats'] = 'ʶԵԢͧ Forum';
 $lang['Admin_Index'] = 'Admin Index';
-$lang['Preview_forum'] = 'Preview Forum';
+$lang['Preview_forum'] = 'Դ Forum 㹽觢';
 
 $lang['Click_return_admin_index'] = 'ԡ %s%s ͡Ѻ˹ Admin Index';
 
 $lang['Statistic'] = 'ʶԵ';
 $lang['Value'] = '';
-$lang['Number_posts'] = 'ӹǹ post';
-$lang['Posts_per_day'] = 'Post ѹ';
+$lang['Number_posts'] = 'ӹǹͤ';
+$lang['Posts_per_day'] = 'ͤѹ';
 $lang['Number_topics'] = 'ӹǹǢ';
 $lang['Topics_per_day'] = 'Ǣ͵ѹ';
 $lang['Number_users'] = 'ӹǹ';
@@ -90,17 +95,18 @@ $lang['OFF'] = '';
 //
 $lang['Database_Utilities'] = 'ͧѺҹ';
 
-$lang['Restore'] = '׹';
-$lang['Backup'] = 'ͧ';
-$lang['Restore_explain'] = '׹ҧ phpBB ҡѹ֡.  server ʹѺʹعúպѴẺ gzip ж١ѵѵ. <b>͹</b> Ҩж١¹Ѻ. á׹ѡ س¹˹ҨҨзӧҹ';
-$lang['Backup_explain'] = 'سöͧŢͧ phpBB. Ҥسյҧǹ㹰ҹ phpBB سͧͧ سһ͹Ф蹴١ ŧ㹵ҧҹҧ.  server ͧѺúպѴẺ gzip зӹǹŷسͧ download ŧ<br>ҧǹǷͧ <b>attach_quota,attachments,attachments_config,attachments_desc,extension_groups,extensions,forbidden_extensions,quota_limits</b>';
+$lang['Restore'] = '׹ҹ';
+$lang['Backup'] = 'ͧҹ';
+$lang['Restore_explain'] = '׹ҹ phpBB ҡѹ֡.  server ʹѺʹعúպѴẺ gzip ж١ѵѵ. <b>͹</b> Ҩж١¹Ѻ. á׹ѡ س¹˹ҨҨзӧҹ';
+$lang['Backup_explain'] = 'سöͧҹŢͧ phpBB . Ҥسյҧǹ㹰ҹ phpBB سͧͧ سһ͹Ф蹴١ ŧ \'ҧ\' ҹҧ.  server ͧѺúպѴẺ gzip зӹǹŷسͧ download ŧ<br>ҧǹǷͧ <b>attach_quota,attachments,attachments_config,attachments_desc,extension_groups,extensions,forbidden_extensions,quota_limits</b>';
 
 $lang['Backup_options'] = 'ͧ͡';
 $lang['Start_backup'] = 'ӡͧ';
-$lang['Full_backup'] = 'ͧẺ';
+$lang['Full_backup'] = 'ͧ';
 $lang['Structure_backup'] = 'ͧ੾çҧ';
 $lang['Data_backup'] = 'ͧ੾Т';
 $lang['Additional_tables'] = 'ҧ';
+$lang['phpBB_only'] = '੾еҧǡѺ phpBB ҹ';
 $lang['Gzip_compress'] = 'úպѴẺ Gzip';
 $lang['Select_file'] = '͡';
 $lang['Start_Restore'] = 'ӡá׹';
@@ -109,7 +115,7 @@ $lang['Restore_success'] = '׹ҹº<br /><br />촨СѺʶҹش·ӡͧ';
 $lang['Backup_download'] = ' download ǹ سѡ';
 $lang['Backups_not_supported'] = '. ҹŹͧѺͧ';
 
-$lang['Restore_Error_uploading'] = ' upload ͧ ԴüԴҴ';
+$lang['Restore_Error_uploading'] = ' upload  ԴüԴҴ';
 $lang['Restore_Error_filename'] = 'ջѭ, سͧ¹';
 $lang['Restore_Error_decompress'] = 'öպѴẺ gzip, س upload 쪹Դѡø';
 $lang['Restore_Error_no_file'] = '١ upload';
@@ -121,16 +127,16 @@ $lang['Restore_Error_no_file'] = '١ upload';
 $lang['Select_a_User'] = '͡';
 $lang['Select_a_Group'] = '͡';
 $lang['Select_a_Forum'] = '͡ forum';
-$lang['Auth_Control_User'] = 'Ǻ͹حҵ'; 
-$lang['Auth_Control_Group'] = 'Ǻ͹حҵ'; 
-$lang['Auth_Control_Forum'] = 'Ǻ͹حҵ forum'; 
-$lang['Look_up_User'] = 'ŧ'; 
-$lang['Look_up_Group'] = 'ŧ'; 
-$lang['Look_up_Forum'] = 'ŧ'; 
+$lang['Auth_Control_User'] = 'Ǻ͹حҵ';
+$lang['Auth_Control_Group'] = 'Ǻ͹حҵ';
+$lang['Auth_Control_Forum'] = 'Ǻ͹حҵ forum';
+$lang['Look_up_User'] = 'ŧ';
+$lang['Look_up_Group'] = 'ŧ';
+$lang['Look_up_Forum'] = 'ŧ';
 
 $lang['Group_auth_explain'] = 'سö¹ŧ͹حҵ ʶҹ moderator ͧС.  ¹ŧ͹حҵͧ ͹حҵѺºؤҨѧ Ҩѧö forum . 㹡óչ سѺ͹.';
 $lang['User_auth_explain'] = 'سö¹ŧ͹حҵ ʶҹ moderator ͧФ.  ¹ŧ͹حҵͧ ͹حҵѺҨѧ Ҩѧö forum . 㹡óչ سѺ͹.';
-$lang['Forum_auth_explain'] = 'سö¹ŧдѺ͹حҵͧ forum. سö͡Ẻҧ Ẻ٧, Ըժ٧äǺ forum С÷ӧҹա. ¹ŧдѺ͹حҵͧ forum ռšѺöзӡõҧ.';
+$lang['Forum_auth_explain'] = 'سö¹ŧдѺ͹حҵͧ forum. سö͡Ẻҧ Ẻ٧, Ըժ٧äǺ forum С÷ӧҹա.';
 
 $lang['Simple_mode'] = 'Ẻ';
 $lang['Advanced_mode'] = 'Ẻ٧';
@@ -162,14 +168,14 @@ $lang['Forum_PRIVATE'] = 'ǹ';
 $lang['Forum_MOD'] = 'MOD';
 $lang['Forum_ADMIN'] = 'ADMIN';
 
-$lang['View'] = '';
-$lang['Read'] = 'ҹ';
-$lang['Post'] = 'Post';
+$lang['View'] = 'Ǣ';
+$lang['Read'] = 'ҹͤ';
+$lang['Post'] = 'Ǣ';
 $lang['Reply'] = 'ͺ';
 $lang['Edit'] = '';
 $lang['Delete'] = 'ź';
 $lang['Sticky'] = 'Sticky';
-$lang['Announce'] = 'С'; 
+$lang['Announce'] = 'ҧС'; 
 $lang['Vote'] = 'ŧṹ';
 $lang['Pollcreate'] = 'ҧẺͺ';
 
@@ -180,63 +186,63 @@ $lang['User_Level'] = 'дѺ';
 $lang['Auth_User'] = '';
 $lang['Auth_Admin'] = 'Administrator';
 $lang['Group_memberships'] = 'ʶҹСҪԡ';
-$lang['Usergroup_members'] = '㹡ªͼѧ';
+$lang['Usergroup_members'] = 'ªͼ㹡ѧ';
 
 $lang['Forum_auth_updated'] = 'Ѻا͹حҵѺ forum ';
 $lang['User_auth_updated'] = 'Ѻا͹حҵѺ';
 $lang['Group_auth_updated'] = 'Ѻا͹حҵѺ';
 
 $lang['Auth_updated'] = 'Ѻا͹حҵ';
-$lang['Click_return_userauth'] = 'ԡ %s%s ͡Ѻ˹ҡ͹حҵѺ';
-$lang['Click_return_groupauth'] = 'ԡ %s%s ͡Ѻ˹ҡ͹حҵѺ';
-$lang['Click_return_forumauth'] = 'ԡ %s%s ͡Ѻ˹ҡ͹حҵѺ forum';
+$lang['Click_return_userauth'] = 'ԡ %s%s ͡Ѻ˹ \'͹حҵѺ\'';
+$lang['Click_return_groupauth'] = 'ԡ %s%s ͡Ѻ˹ \'͹حҵѺ\'';
+$lang['Click_return_forumauth'] = 'ԡ %s%s ͡Ѻ˹ \'͹حҵѺ forum\'';
 
 
 //
 // Banning
 //
-$lang['Ban_control'] = 'Ǻǧ';
-$lang['Ban_explain'] = 'سöǺǧ. سöǧºؤ / ͧ IP address  hostnames. ԸչлͧѹҶ֧˹áͧ. ҨлͧѹҡѤҪԡ͵ҧ سöк e-mail ͧǧ. ǧ e-mail §ҧǨöͧѹ鹨ҡк ʵ㹺 س˹ͧԸáѺ䢻ѭҹ.';
+$lang['Ban_control'] = 'Ǻ';
+$lang['Ban_explain'] = 'سöǺ. سöºؤ / ͧ IP address  hostnames. ԸչлͧѹҶ֧˹áͧ. ҨлͧѹҡѤҪԡ͵ҧ سöк e-mail ͧ.  e-mail §ҧǨöͧѹ鹨ҡк 觢ͤ㹺 س˹ͧԸáѺ䢻ѭҹ.';
 $lang['Ban_explain_warn'] = 'ôѧ кءͧ IP address ռšѺء IP ҧ IP ش. Ţ IP кѹ֡ŧҹŨ wildcards ѵѵŴҴͧ IP. Ҥسͧкتǧͧ IP ԧ سкتǧ᤺شҷз.';
 
 $lang['Select_username'] = '͡ username';
 $lang['Select_ip'] = '͡ IP';
 $lang['Select_email'] = '͡ Email';
 
-$lang['Ban_username'] = 'ǧ 1 ҡ';
-$lang['Ban_username_explain'] = 'سöǧ¤㹤 Фѹ';
+$lang['Ban_username'] = ' 1 ҡ';
+$lang['Ban_username_explain'] = 'سö¤㹤 Фѹ';
 
-$lang['Ban_IP'] = 'ǧ IP 1 Ţҡ ͪ host';
+$lang['Ban_IP'] = ' IP 1 Ţҡ ͪ host';
 $lang['IP_hostname'] = 'Ţ IP ͪ host';
 $lang['Ban_IP_explain'] = 'кŢ IP  hostname Ъʹ١. Ҩкتǧͧ IP ¡Ţش¢մ (-), Ҩк wildcard  *';
 
-$lang['Ban_email'] = 'ǧ 1 Email ҡ';
+$lang['Ban_email'] = ' 1 Email ҡ';
 $lang['Ban_email_explain'] = 'Ҩкҡ 1 email 蹴١. Ҩк wildcard  *  *@hotmail.com';
 
-$lang['Unban_username'] = '¡ԡǧ 1 ҡ';
-$lang['Unban_username_explain'] = 'سö¡ԡǧª㹤 Фѹ';
+$lang['Unban_username'] = '¡ԡ 1 ҡ';
+$lang['Unban_username_explain'] = 'سö¡ԡª㹤 Фѹ';
 
-$lang['Unban_IP'] = '¡ԡǧ IP 1Ţҡ';
-$lang['Unban_IP_explain'] = 'سö¡ԡǧ IP 㹤 Фѹ';
+$lang['Unban_IP'] = '¡ԡ IP 1 Ţҡ';
+$lang['Unban_IP_explain'] = 'سö¡ԡ IP 㹤 Фѹ';
 
-$lang['Unban_email'] = '¡ԡǧ 1 Email ҡ';
-$lang['Unban_email_explain'] = 'سö¡ԡǧ email 㹤 Фѹ';
+$lang['Unban_email'] = '¡ԡ 1 Email ҡ';
+$lang['Unban_email_explain'] = 'سö¡ԡ email 㹤 Фѹ';
 
-$lang['No_banned_users'] = 'աǧ';
-$lang['No_banned_ip'] = 'աǧŢ IP';
-$lang['No_banned_email'] = 'աǧ Email';
+$lang['No_banned_users'] = 'ա';
+$lang['No_banned_ip'] = 'աŢ IP';
+$lang['No_banned_email'] = 'ա Email';
 
-$lang['Ban_update_sucessful'] = 'Ѻاª͡ǧ';
-$lang['Click_return_banadmin'] = 'ԡ %s%s ͡Ѻ˹ҤǺǧ';
+$lang['Ban_update_sucessful'] = 'Ѻاª͡';
+$lang['Click_return_banadmin'] = 'ԡ %s%s ͡Ѻ˹ \'Ǻ\'';
 
 
 //
 // Configuration
 //
 $lang['General_Config'] = 'õ駤ҷ';
-$lang['Config_explain'] = 'Ẻҹҧ سѺ觤ҵҧͧ. ԧǢͧ觫 ͡õ駤Ѻ forum .';
+$lang['Config_explain'] = 'Ẻҹҧ سѺ觤ҵҧͧ. ҵͧõ駤Ѻ forum ԧ觫᷹.';
 
-$lang['Click_return_config'] = 'ԡ %s%s ͡Ѻ˹ҡõ駤ҷ';
+$lang['Click_return_config'] = 'ԡ %s%s ͡Ѻ˹ \'õ駤ҷ\'';
 
 $lang['General_settings'] = '駤ҷ仢ͧ';
 $lang['Server_name'] = 'Domain Name';
@@ -251,26 +257,26 @@ $lang['Board_disable'] = '¡ԡ';
 $lang['Board_disable_explain'] = 'ҹ. ͡ҡкͤس¡ԡ Фسöкա!';
 $lang['Acct_activation'] = 'ͧ׹ѹѭմ';
 $lang['Acc_None'] = 'ͧ'; // These three entries are the type of activation
-$lang['Acc_User'] = 'User';
-$lang['Acc_Admin'] = 'Admin';
+$lang['Acc_User'] = '׹ѹҡԧ email';
+$lang['Acc_Admin'] = 'Admin 繼׹ѹ';
 
 $lang['Abilities_settings'] = 'õ駤Ҿ鹰ҹͧ forum';
 $lang['Max_poll_options'] = 'ӹǹ͡ѺẺͺ Թ';
-$lang['Flood_Interval'] = 'һͧѹ觢ͤӡѹ';
-$lang['Flood_Interval_explain'] = 'ӹǹԹҷ ͧҧ post'; 
+$lang['Flood_Interval'] = 'һͧѹ觢ͤѹ';
+$lang['Flood_Interval_explain'] = 'ӹǹԹҷշͧ ҧ觢ͤԴѹ'; 
 $lang['Board_email_form'] = ' Email ҧҹ';
 $lang['Board_email_form_explain'] = '͹حҵ Email ֧ѹ ҹͧ촹';
 $lang['Topics_per_page'] = 'ӹǹǢ͵˹';
-$lang['Posts_per_page'] = 'ӹǹʵ˹';
-$lang['Hot_threshold'] = 'ӹǹʵ Ѻ';
+$lang['Posts_per_page'] = 'ӹǹͤ˹';
+$lang['Hot_threshold'] = 'ӹǹõͺ Ѻ';
 $lang['Default_style'] = 'ٻẺҵðҹ';
 $lang['Override_style'] = 'ѧѺѺء';
 $lang['Override_style_explain'] = '᷹ٻẺͧ͡ ٻẺҵðҹ';
 $lang['Default_language'] = 'ҵðҹ';
-$lang['Date_format'] = 'ٻẺѹ';
+$lang['Date_format'] = 'ٻẺѹҵðҹ';
 $lang['System_timezone'] = 'ûѺ timezone';
 $lang['Enable_gzip'] = 'úպѴẺ GZip';
-$lang['Enable_prune'] = 'źѵѵ forum';
+$lang['Enable_prune'] = 'ź forum ռͺҹԹ';
 $lang['Allow_HTML'] = ' HTML';
 $lang['Allow_BBCode'] = ' BBCode';
 $lang['Allowed_tags'] = ' HTML';
@@ -279,14 +285,14 @@ $lang['Allow_smilies'] = 'ٻ';
 $lang['Smilies_path'] = '˹觷ٻ';
 $lang['Smilies_path_explain'] = ' rood directory ͧ phpBB  images/smiles';
 $lang['Allow_sig'] = '';
-$lang['Max_sig_length'] = ' Թ';
+$lang['Max_sig_length'] = ' Թ [ ѡ ]';
 $lang['Max_sig_length_explain'] = 'ӹǹѡ٧شͧ';
 $lang['Allow_name_change'] = '¹ username';
 
 $lang['Avatar_settings'] = 'õ駤ٻШӵ';
-$lang['Allow_local'] = 'ٻ';
-$lang['Allow_remote'] = 'ٻҡ';
-$lang['Allow_remote_explain'] = 'ٻШӵǷ躹';
+$lang['Allow_local'] = 'öٻҵðҹ';
+$lang['Allow_remote'] = 'öٻҡ URL ';
+$lang['Allow_remote_explain'] = 'ٻҾ躹 ٻШӵ';
 $lang['Allow_upload'] = 'ö upload ٻШӵ';
 $lang['Max_filesize'] = 'ҴٻШӵ Թ';
 $lang['Max_filesize_explain'] = 'Ѻ upload ٻШӵ';
@@ -307,7 +313,7 @@ $lang['Admin_email'] = 'Email ͧ Admin';
 $lang['Email_sig'] = '繢ͧ Email';
 $lang['Email_sig_explain'] = 'ͤṺ仡Ѻ Email ءѺ 觨ҡ';
 $lang['Use_SMTP'] = ' SMTP Server 㹡 Email';
-$lang['Use_SMTP_explain'] = 'ͺ  ͤسͧͨ繵ͧ Email ҹ SMTP server ᷹ѧѹ Email ͧͧ';
+$lang['Use_SMTP_explain'] = 'ͺ \'\' ͤسͧͨ繵ͧ Email ҹ SMTP server ᷹ѧѹ Email ͧͧ';
 $lang['SMTP_server'] = 'ͧ SMTP Server';
 $lang['SMTP_username'] = 'SMTP Username';
 $lang['SMTP_username_explain'] = '͹ username ͨ繵ͧҹ';
@@ -328,12 +334,15 @@ $lang['Cookie_secure'] = 'ʹ¢ͧ Cookie';
 $lang['Cookie_secure_explain'] = ' server ͧس SSL Դҹ';
 $lang['Session_length'] = ' [ Թҷ ]';
 
+// Visual Confirmation
+$lang['Visual_confirm'] = 'Դ׹ѹٻҾ';
+$lang['Visual_confirm_explain'] = 'еͧ͡ʷٻҾͷӡѤҪԡ';
 
 //
 // Forum Management
 //
-$lang['Forum_admin'] = 'Forum Administration';
-$lang['Forum_admin_explain'] = 'ǹس, ź, , §ӴѺ, Ѵ§ forum ';
+$lang['Forum_admin'] = 'èѴ forum';
+$lang['Forum_admin_explain'] = 'ǹسö, ź, , §ӴѺ, Ѵ§ forum ';
 $lang['Edit_forum'] = ' forum';
 $lang['Create_forum'] = 'ҧ forum ';
 $lang['Create_category'] = 'ҧ';
@@ -345,9 +354,9 @@ $lang['Edit'] = '';
 $lang['Delete'] = 'ź';
 $lang['Move_up'] = '͹';
 $lang['Move_down'] = '͹ŧ';
-$lang['Resync'] = '§ӴѺ';
+$lang['Resync'] = 'Ѵº';
 $lang['No_mode'] = 'աõ mode';
-$lang['Forum_edit_delete_explain'] = 'Ẻҹҧ سѺ觡õ駤ҷ仢ͧ. ԧ觫 ͡õ駤Ѻ forum';
+$lang['Forum_edit_delete_explain'] = 'Ẻҹҧ س䢢´ͧ forum ͡';
 
 $lang['Move_contents'] = '¢ͤ';
 $lang['Forum_delete'] = 'ź forum';
@@ -361,8 +370,8 @@ $lang['Forum_desc'] = '´';
 $lang['Forum_status'] = 'ʶҹТͧ forum';
 $lang['Forum_pruning'] = 'źѵѵ';
 
-$lang['prune_freq'] = 'ǨͺآͧǢͷء';
-$lang['prune_days'] = 'ʹǢ͡ ա post Թ';
+$lang['prune_freq'] = 'ǨͺǢͷ forum ء';
+$lang['prune_days'] = 'źǢ աõͺԹ';
 $lang['Set_prune_data'] = 'سԴкźǢѵѵ Ѻ forum  ͨӹǹѹ͵Ǩͺ. سҤԡ back ͡Ѻ';
 
 $lang['Move_and_Delete'] = 'ź';
@@ -370,34 +379,34 @@ $lang['Move_and_Delete'] = 'ź';
 $lang['Delete_all_posts'] = 'źͤ';
 $lang['Nowhere_to_move'] = 'кػ·ҧ';
 
-$lang['Edit_Category'] = '䢡';
+$lang['Edit_Category'] = '䢪͡';
 $lang['Edit_Category_explain'] = 'Ẻ䢪͡.';
 
 $lang['Forums_updated'] = 'ѺاŢͧ forum С';
 
 $lang['Must_delete_forums'] = 'سеͧźء forum ͹ź';
 
-$lang['Click_return_forumadmin'] = 'ԡ %s%s ͡Ѻ˹ Forum Administration';
+$lang['Click_return_forumadmin'] = 'ԡ %s%s ͡Ѻ˹ \'èѴ Forum\'';
 
 
 //
 // Smiley Management
 //
 $lang['smiley_title'] = 'ͧٻ';
-$lang['smile_desc'] = '˹ҹ سö, ź  ٻʴ ٻ ö㹢ͤʵТͤǹ.';
+$lang['smile_desc'] = '˹ҹ سö, ź  ٻʴ ٻ ö㹢ͤТͤǹ.';
 
 $lang['smiley_config'] = 'õ駤ٻ';
-$lang['smiley_code'] = 'ٻ';
+$lang['smiley_code'] = 'Code';
 $lang['smiley_url'] = 'ٻҾ';
-$lang['smiley_emot'] = 'ٻҾʴ';
+$lang['smiley_emot'] = '͸Ժ';
 $lang['smile_add'] = 'ٻ';
 $lang['Smile'] = 'ٻ';
-$lang['Emotion'] = 'ٻʴ';
+$lang['Emotion'] = '͸Ժ';
 
 $lang['Select_pak'] = '͡ Pack (.pak)';
 $lang['replace_existing'] = '᷹ٻ';
 $lang['keep_existing'] = 'ٻ';
-$lang['smiley_import_inst'] = 'س unzip 礢ͧٻ 觷ء价 directory Ѻٻ͡õԴ.  ҡ͡ŷ١ͧẺ ͹ٻ.';
+$lang['smiley_import_inst'] = 'س unzip 礢ͧٻ 觷ء价 directory ٻ ͹ӡõԴ. ҡ͡ŷ١ͧẺ ͹ٻ.';
 $lang['smiley_import'] = '礢ͧٻ';
 $lang['choose_smile_pak'] = '͡ (.pak) ͧٻ';
 $lang['import'] = 'ٻ';
@@ -405,26 +414,26 @@ $lang['smile_conflicts'] = 'èзҧ;ٻ';
 $lang['del_existing_smileys'] = 'źٻҡ͹';
 $lang['import_smile_pack'] = '礢ͧٻ';
 $lang['export_smile_pack'] = 'ҧ礢ͧٻ';
-$lang['export_smiles'] = 'ҧ礢ͧٻҡٻԴ ԡ %s%s  download  smiles.pak Ǩ͹ҹءŢͧ .pak ҡҧ zip èٻҾ Ѻõ駤 .pak ';
+$lang['export_smiles'] = 'ҧ礢ͧٻҡٻԴ ԡ %s%s  download  smiles.pak Ǩ͹ҹءŢͧ .pak ҡ download ٻҾ  smiles.pak ٻҾ ҧ zip';
 
 $lang['smiley_add_success'] = 'ٻº';
 $lang['smiley_edit_success'] = 'Ѻاٻº';
 $lang['smiley_import_success'] = '礢ͧٻº';
 $lang['smiley_del_success'] = 'źٻº';
-$lang['Click_return_smileadmin'] = 'ԡ %s%s ͡Ѻ Smiley Administration';
+$lang['Click_return_smileadmin'] = 'ԡ %s%s ͡Ѻ˹ \'ٻ\'';
 
 
 //
 // User Management
 //
-$lang['User_admin'] = 'User Administration';
+$lang['User_admin'] = 'õ駤Һѭռ';
 $lang['User_admin_explain'] = 'سö¹ŧ´ͧ е͡ҧ. Ҩ䢡͹حҵ к͹حҵѺС';
 
 $lang['Look_up_user'] = 'ŧ';
 
 $lang['Admin_user_fail'] = 'öѺاǹǢͧ';
 $lang['Admin_user_updated'] = 'ѺاǹǢͧ';
-$lang['Click_return_useradmin'] = 'ԡ %s%s ͡Ѻ˹ User Administration';
+$lang['Click_return_useradmin'] = 'ԡ %s%s ͡Ѻ˹ \'õ駤Һѭռ\'';
 
 $lang['User_delete'] = 'ź';
 $lang['User_delete_explain'] = 'ԡź, ö¡ԡ';
@@ -443,7 +452,7 @@ $lang['User_special_explain'] = 'ǹö¼. سöʶҹе͡ ö';
 //
 // Group Management
 //
-$lang['Group_administration'] = 'Group Administration';
+$lang['Group_administration'] = 'õ駤ҡ';
 $lang['Group_admin_explain'] = 'سöѴá سö ź, ҧ 䢡 سҨ͡ moderator, ѺʶҹԴ/Դ е駪͡Ф͸Ժ';
 $lang['Error_updating_groups'] = 'ԴͼԴҴҧѺا';
 $lang['Updated_group'] = 'Ѻاº';
@@ -468,7 +477,7 @@ $lang['No_group_mode'] = 'سͧкʶҹТͧ Դ Ͷ١Դ';
 $lang['No_group_action'] = 'кءáз';
 $lang['delete_group_moderator'] = 'ź moderator Ңͧ?';
 $lang['delete_moderator_explain'] = 'Ҥسѧ¹ŧ moderator ͧ ͧ͡ź moderator ͡ҡ Ͷ͡ СҪԡҢͧ';
-$lang['Click_return_groupsadmin'] = 'ԡ %s%s ͡Ѻ Group Administration.';
+$lang['Click_return_groupsadmin'] = 'ԡ %s%s ͡Ѻ \'õ駤ҡ\'';
 $lang['Select_group'] = '͡';
 $lang['Look_up_group'] = 'ŧ';
 
@@ -476,14 +485,14 @@ $lang['Look_up_group'] = 'ŧ';
 //
 // Prune Administration
 //
-$lang['Forum_Prune'] = 'źѵѵ forum';
-$lang['Forum_Prune_explain'] = 'źǢͷռ post ӹǹѹ˹. Ҥسкبӹǹѹ, ءǢͨж١ź. ʹǢͷẺͺѧӧҹ ШʹͤС. سеͧʹǢҹµͧ.';
-$lang['Do_Prune'] = 'ӡźѵѵ';
+$lang['Forum_Prune'] = 'źǢͷաõͺ';
+$lang['Forum_Prune_explain'] = 'źǢͷռͺӹǹѹ˹. Ҥسкبӹǹѹ, ءǢͨж١ź. źǢͷẺͺѧӧҹ ШźͤС. سеͧźǢҹµͧ.';
+$lang['Do_Prune'] = 'ŧ';
 $lang['All_Forums'] = 'ء forum';
-$lang['Prune_topics_not_posted'] = 'źǢͷաõͺ繨ӹǹѹ';
-$lang['Topics_pruned'] = 'Ǣͷ١źѵѵ';
-$lang['Posts_pruned'] = 'Post ١źѵѵ';
-$lang['Prune_success'] = 'ӡźѵѵ forum ';
+$lang['Prune_topics_not_posted'] = 'źǢͷաõͺҹԹ';
+$lang['Topics_pruned'] = 'ӹǹǢͷ١ź';
+$lang['Posts_pruned'] = 'ӹǹͤ١ź';
+$lang['Prune_success'] = 'ӡź forum º';
 
 
 //
@@ -504,26 +513,26 @@ $lang['Word_updated'] = 'Ѻاǧ١͡º';
 $lang['Word_added'] = 'ǧº';
 $lang['Word_removed'] = 'źǧ١͡º';
 
-$lang['Click_return_wordadmin'] = 'ԡ %s%s ͡Ѻ˹ Word Censor Administration';
+$lang['Click_return_wordadmin'] = 'ԡ %s%s ͡Ѻ˹ \'ǧ\'';
 
 
 //
 // Mass Email
 //
-$lang['Mass_email_explain'] = 'سö e-mail ء ͼء㹡к. Email ж١价 email address ͧ admin к  BCC (blind carbon copy) Ѻء. Ҥس email ˭ سʹѧ ҡشҧ÷ӧҹ. ˵ءóáԷͧҹҹ سѺкӧҹº';
+$lang['Mass_email_explain'] = 'سö e-mail ء ͼء㹡к. Email 鹩Ѻж١价 email address ͧ admin к  BCC (blind carbon copy) Ѻء. Ҥس email ˭ سʹѧ ҡشҧ÷ӧҹ. ˵ءóáԷͧҹҹ سѺкӧҹº';
 $lang['Compose'] = '¹ email'; 
 
 $lang['Recipients'] = 'Ѻ'; 
 $lang['All_users'] = 'ء';
 
 $lang['Email_successfull'] = 'ͤ١';
-$lang['Click_return_massemail'] = 'ԡ %s%s ͡ѺẺ Mass Email';
+$lang['Click_return_massemail'] = 'ԡ %s%s ͡ѺẺ \' Email 繡\'';
 
 
 //
 // Ranks admin
 //
-$lang['Ranks_title'] = 'Rank Administration';
+$lang['Ranks_title'] = 'дѺ';
 $lang['Ranks_explain'] = 'سö, ,  źдѺ. ФسöҧдѺѺ ҹҧèѴü';
 
 $lang['Add_new_rank'] = 'дѺ';
@@ -543,7 +552,7 @@ $lang['Rank_added'] = 'дѺº';
 $lang['Rank_removed'] = 'źдѺº';
 $lang['No_update_ranks'] = 'źдѺº ҼѧдѺ鹹ѧѺûѺا. سеͧЪͺѭմµͧ';
 
-$lang['Click_return_rankadmin'] = 'ԡ %s%s ͡Ѻ Rank Administration';
+$lang['Click_return_rankadmin'] = 'ԡ %s%s ͡Ѻ˹ \'дѺ\'';
 
 
 //
@@ -566,15 +575,15 @@ $lang['Disallowed_deleted'] = 'ź username ͹حҵ';
 $lang['Disallow_successful'] = ' username ͹حҵ';
 $lang['Disallowed_already'] = 'ö username . Ҩ username ¡, 㹡Һ,  username ';
 
-$lang['Click_return_disallowadmin'] = 'ԡ %s%s ͡Ѻ˹ Disallow Username Administration';
+$lang['Click_return_disallowadmin'] = 'ԡ %s%s ͡Ѻ˹ \'\'';
 
 
 //
 // Styles Admin
 //
-$lang['Styles_admin'] = 'Styles Administration';
+$lang['Styles_admin'] = 'õ駤ٻẺ';
 $lang['Styles_explain'] = 'سö, ź ШѴٻẺ (template  theme) Ѻ';
-$lang['Styles_addnew_explain'] = '¡ùٻẺس. ҧٻẺҨѧѺõԴŧҹ phpBB. ԡ Դ ҹҧͧٻẺ';
+$lang['Styles_addnew_explain'] = '¡ùٻẺس. ҧٻẺҨѧѺõԴŧҹ phpBB. ԡ \'Դ\' ҹҢͧٻẺ';
 
 $lang['Select_template'] = '͡ template';
 
@@ -606,7 +615,7 @@ $lang['No_template_dir'] = 'öԴ template directory. Ҩж١ҹ webserver Ҩԧ';
 $lang['Cannot_remove_style'] = 'سöźٻẺ͡ ѹ١ٻẺҵðҹ. س¹ٻẺҵðҹͧ.';
 $lang['Style_exists'] = 'ժͧ͢ٻẺ سҡѺ¹.';
 
-$lang['Click_return_styleadmin'] = 'ԡ %s%s ͡Ѻ˹ Style Administration';
+$lang['Click_return_styleadmin'] = 'ԡ %s%s ͡Ѻ˹ \'õ駤ٻẺ\'';
 
 $lang['Theme_settings'] = '駤 theme';
 $lang['Theme_element'] = 'ǹСͺͧ theme';
@@ -664,14 +673,14 @@ $lang['Welcome_install'] = 'Թյ͹ѺõԴ phpBB 2';
 $lang['Initial_config'] = 'õ駤Ҿ鹰ҹ';
 $lang['DB_config'] = 'õ駤Ұҹ';
 $lang['Admin_config'] = 'õ駤 Admin';
-$lang['continue_upgrade'] = 'ͤس download õ駤ŧͧͧس ԡ ӡѻô ҹҧ ѧкǹѻô. س͢зӡõ駤 ҡкǹѻô.';
+$lang['continue_upgrade'] = 'ͤس download õ駤ŧͧͧس ԡ \'ӡѻô\' ҹҧ ѧкǹѻô. س͢зӡõ駤 ҡкǹѻô.';
 $lang['upgrade_submit'] = 'ӡѻô';
 
 $lang['Installer_Error'] = 'ԴͼԴҴҧõԴ';
 $lang['Previous_Install'] = 'ǨաõԴҡ͹';
 $lang['Install_db_error'] = 'ԴͼԴҴ㹡þѺاҹ';
 
-$lang['Re_install'] = 'õԴ駤駡͹ѧ. <br /><br />ҤسͧõԴ phpBB 2  سäԡ Yes ҹҧ. ôѧҡ÷蹹 з¢ŷ աͧ! ʼҹͧ administrator سж١ҧ աõ駤ŧա<br /><br />سҤԴͺͺ͹ԡ Yes!';
+$lang['Re_install'] = 'õԴ駤駡͹ѧ. <br /><br />ҤسͧõԴ phpBB 2  سäԡ Yes ҹҧ. ôѧҡ÷蹹 з¢ŷ Шաͧ! ʼҹͧ administrator سж١ҧ աõ駤ŧա<br /><br />سҤԴͺͺ͹ԡ Yes!';
 
 $lang['Inst_Step_0'] = 'ͺس phpBB 2. õԴó سҡ͡´ҹҧ. سҵǨͺ͹ҪͰҹŷس١ҧ͹. ҤسѧԴŧҹ ODBC  MS Access سèҧ DSN ¡͹';
 
@@ -691,22 +700,22 @@ $lang['Admin_Username'] = 'Administrator Username';
 $lang['Admin_Password'] = 'Administrator Password';
 $lang['Admin_Password_confirm'] = 'Administrator Password [׹ѹ]';
 
-$lang['Inst_Step_2'] = 'ҧѭ admin ͧس. йõԴ駾鹰ҹó. سж١ѧ˹Ѻõ駤ҷ. سҵǨͺ´ͧ õ駤ҷ ǹͧ. ͺس phpBB 2.';
+$lang['Inst_Step_2'] = 'ҧѭ admin ͧس. йõԴ駾鹰ҹó. سж١ѧ˹Ѻõ駤ҷ. سҵǨͺ´ͧ \'õ駤ҷ\' ǹͧ. ͺس phpBB 2.';
 
-$lang['Unwriteable_config'] = 'õ駤Ңͧس ١˹Էö. ͤسԡҹҧ õ駤Ҩж١س download. س upload  directory ǡѹѺ phpBB 2. кºѭբͧ administrator ͡ ҡ价 Admin Control Panel (ԧҹҧͧ˹ к) ͵Ǩͺõ駤ҷ. ͺس phpBB 2.';
+$lang['Unwriteable_config'] = 'õ駤Ңͧس ١˹Էö. ͤسԡҹҧ õ駤Ҩж١س download. س upload Ѻ directory ǡѹѺ phpBB 2. кºѭբͧ administrator ͡ ҡ价 Admin Control Panel (ԧҹҧͧ˹ к) ͵Ǩͺõ駤ҷ. ͺس phpBB 2.';
 $lang['Download_config'] = 'Download õ駤';
 
 $lang['ftp_choose'] = '͡Ըա Download';
-$lang['ftp_option'] = '<br />աõԴк FTP ŧ PHP 蹹 سҨк ftp ѵѵ';
-$lang['ftp_instructs'] = 'س͡к ftp ѵѵ. سҡ͡Ŵҹҧ. ˹ FTP èеçѺ˹ ftp ӡõԴ phpBB2 ͹ҧس ftp ';
+$lang['ftp_option'] = '<br />աõԴк FTP ŧ PHP 蹹 سҨк FTP ѵѵ';
+$lang['ftp_instructs'] = 'س͡к FTP ѵѵ. سҡ͡Ŵҹҧ. ˹ FTP èеçѺ˹ FTP ӡõԴ phpBB2 ͹ҧس FTP ';
 $lang['ftp_info'] = 'سҡ͡ FTP ͧس';
-$lang['Attempt_ftp'] = '駤ҡ ftp ';
-$lang['Send_file'] = 'ѹ ǩѹ ftp  仴µͧ';
+$lang['Attempt_ftp'] = '駤ҡ FTP ';
+$lang['Send_file'] = 'ѹ ǩѹ FTP  upload ׹µͧ';
 $lang['ftp_path'] = '˹ FTP ͧ phpBB 2';
 $lang['ftp_username'] = 'FTP Username';
 $lang['ftp_password'] = 'FTP Password';
 $lang['Transfer_config'] = '';
-$lang['NoFTP_config'] = 'þõ駤ҷҧ ftp . س download õ駤 ҷҧ ftp µǤسͧ';
+$lang['NoFTP_config'] = 'þõ駤ҷҧ FTP . س download õ駤 ҷҧ FTP µǤسͧ';
 
 $lang['Install'] = 'Դ';
 $lang['Upgrade'] = 'ѻô';
